@@ -6,7 +6,7 @@
 
 #include <stdlib.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void) a64l("2317");
     (void) l64a(2317);
