@@ -6,7 +6,7 @@
 
 #include <stdlib.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     abs(-23);
 }
