@@ -6,7 +6,7 @@
 
 #include <unistd.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     /* 
      * Note: use of a symbolic constant like F_OK *will* 
