@@ -6,7 +6,7 @@
 
 #include <math.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     asin(-23.0);
 }
