@@ -6,7 +6,7 @@
 
 #include <math.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     atan2(-23.0, 17.0);
 }
