@@ -6,7 +6,7 @@
 
 #include <libgen.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void)basename("/dev/null");
 }
