@@ -6,7 +6,7 @@
 
 #include <strings.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void) bzero(0, 0);
 }
