@@ -6,7 +6,7 @@
 
 #include <nl_types.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void) catgets(0, 0, 0, "foobar");
 }
