@@ -6,7 +6,7 @@
 
 #include <termios.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     struct termios t;
     cfgetospeed(&t);
