@@ -7,7 +7,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void)chown("/", 0, 0);
 }
