@@ -6,7 +6,7 @@
 
 #include <stdio.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void)clearerr(stdin);
 }
