@@ -6,7 +6,7 @@
 
 #include <time.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     struct timespec ts;
     (void)clock_getres(0, &ts);
