@@ -3,6 +3,6 @@
 #include <stdio.h>
 #include <stdio.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
 }
