@@ -6,7 +6,7 @@
 
 #include <sys/stat.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void)fchmod(0, 0);
 }
