@@ -6,7 +6,7 @@
 
 #include <unistd.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     (void)fchown(0, 0, 0);
 }
