@@ -7,7 +7,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     fstat(0, 0);
 }
