@@ -1,5 +1,5 @@
 /* this file has no headers and needs none */
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
 }
