@@ -2,6 +2,6 @@
 
 #include <string.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
 }
