@@ -8,7 +8,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-main(int arg, char **argv)
+int main(int arg, char **argv)
 {
     umask(777);
 }
